@@ -1,6 +1,6 @@
 package Plack::Middleware::TemplateToolkit;
 # ABSTRACT: Serve files with Template Toolkit and Plack
-$Plack::Middleware::TemplateToolkit::VERSION = '0.27';
+$Plack::Middleware::TemplateToolkit::VERSION = '0.28';
 use strict;
 use warnings;
 use 5.008_001;
@@ -22,7 +22,7 @@ our @TT_CONFIG;
 our @DEPRECATED;
 
 BEGIN {
-    @TT_CONFIG = qw(START_TAG END_TAG TAG_STYLE PRE_CHOMP POST_CHOMP TRIM
+    @TT_CONFIG = qw(ENCODING START_TAG END_TAG OUTLINE_TAG TAG_STYLE PRE_CHOMP POST_CHOMP TRIM
         INTERPOLATE ANYCASE INCLUDE_PATH DELIMITER ABSOLUTE RELATIVE DEFAULT
         BLOCKS VIEWS AUTO_RESET RECURSION VARIABLES CONSTANTS
         CONSTANT_NAMESPACE NAMESPACE PRE_PROCESS POST_PROCESS PROCESS WRAPPER
